@@ -125,18 +125,31 @@ class Instrument:
         ret.columns = colnames
         return ret
 
-    def get_tradable_contracts(self, prefix='IF'):
+    def get_tradable_contracts(self, prefix='IF') -> pd.DataFrame:
         """
         Return 4 tradable Futures codes of an Instrument instance
 
         Examples
         --------
-        >>> ins = Instrument("20210908", morning=True)
+        >>> ins = Instrument("20220722", morning=True)
         >>> ins.get_tradable_contracts()
-        >>> [('IF2203',), ('IF2112',), ('IF2110',), ('IF2109',)]
+        >>> code
+            0   IF2303
+            1   IF2212
+            2   IF2209
+            3   IF2208
+            4   IF2207
+            5   IF2206
+        >>> ins.get_tradable_contracts(prefix='IM')
+        >>> code
+            0  IM2303
+            1  IM2212
+            2  IM2209
+            3  IM2208
         """
         conn = sqlite3.connect(self.cache)
         cur = conn.cursor()
-        cur.execute(f"SELECT code FROM Futures WHERE (Code LIKE '%{prefix}%') ORDER BY code DESC LIMIT 4;")
+        cur.execute(f"SELECT code FROM Futures WHERE (Code LIKE '%{prefix}%') ORDER BY code DESC;")
         ret = cur.fetchall()
+        ret = pd.DataFrame(ret, columns=['code'])
         return ret
\ No newline at end of file
