@@ -23,10 +23,10 @@ class TestPitrading(unittest.TestCase):
 
     def test_000_something(self):
         """Test something."""
-        ds = Holidays.to_datetime('20220101')
+        ds = Holidays.to_datetime('20220702')
         while ds <= Holidays.to_datetime('20220722'):
             if Holidays.tradingday(ds):
-                Instrument(ds.strftime('%Y%m%d'), morning=True).get_tradable_contracts()
+                Instrument(ds.strftime('%Y%m%d'), morning=True).get_tradable_contracts(prefix='IM')
             ds += timedelta(days=10)
             
         
\ No newline at end of file
